{% extends "admin/base.html" %}

{% block content_title %}
    <h1>403 Forbidden</h1>
{% endblock content_title %}

{% block content %}
    <p>You are not allowed to access this page</p>
{% endblock content %}
