{% extends "admin/change_form.html" %}{% load admin_modify admin_urls i18n static %}
{% block breadcrumbs %}
<div class="breadcrumbs">
<a href="{% url 'admin:index' %}">{% translate 'Home' %}</a>
&rsaquo; <a href="{% url 'admin:app_list' app_label=opts.app_label %}">{{ opts.app_config.verbose_name }}</a>
&rsaquo; <a href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a>
&rsaquo; Import
</div>
{% endblock breadcrumbs %}

{% block content %}
<h1>Import Users</h1>
<h3>Type a list of email or partial usernames to be synchronized with Azure AD</h3>
<form method="POST" id="load_users" novalidate>
    {% csrf_token %}
    {{ form }}
    <div><input type="submit" value="Import"></div>
</form>
{% endblock content %}

{% block submit_buttons_bottom %}{% endblock %}
