{% extends "admin/base_site.html" %}{% load admin_modify admin_urls i18n static %}

{% block breadcrumbs %}
    <div class="breadcrumbs">
        <a href="{% url 'admin:index' %}">{% translate 'Home' %}</a>
        &rsaquo; <a href="{% url 'admin:app_list' app_label=opts.app_label %}">{{ opts.app_config.verbose_name }}</a>
        &rsaquo; <a href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a>
        &rsaquo; AD User
    </div>
{% endblock breadcrumbs %}

{% block content %}

<table>
    {% for key, value in ctx.items %}
    <tr><td>{{ key }}</td><td>{{ value }}</td></tr>
    {% endfor %}
</table>
{% endblock content %}
