<!doctype html>

<html lang="">

<head>
    <meta http-equiv="X-UA-Compatible" content="IE=edge" />
    <meta charset="utf-8">
    <meta name="description" content="">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="generator" content="UNICEF" />
    <title>{% block title %} UNICEF {% endblock %}</title>
    <meta name="theme-color" content="#2E3AA1">

    {% block extra_head %}

    <style>
        body {
            padding: 0;
            margin: 0;
            background-color: rgba(21, 39, 79, 0.2);
        }
        .medium-tall{
            padding: 1%;
            background-color: rgb(21, 39, 79);
            color: #ffffff;
        }

        .content{
            display: block;
            text-align: center;
            background-image: url("/api/static/images/IP-Landing-Page-sm.jpeg");
            background-repeat: no-repeat;
            background-position: center;
            background-blend-mode: multiply;
            opacity: 0.8;
            padding-top:0;
        }
        .messsage {
            padding-top: 50px;
            padding-bottom: 300px;
            color:white;
            font-size: 17px;
        }

    </style>


    {% endblock extra_head %}

</head>

<body class="fullbleed vertical layout">
{% block toolbar %}
<div class="medium-tall">
    <img src="/api/static/images/IP-logo.png" width="200px">
</div>
{% endblock toolbar %}


{% block content %}
<div class="content">

    <div class="messsage">
        <header>
            <h1 class="error primary-txt">Not authorized</h1>
        </header>

    <h3> Hi {% if user.is_authenticated %} {{ user }} {% else %} {{ request.GET.eu }}{% endif %}, </h3>
        <br>
        <a href="/" style="color:white">Home</a>
        <br><br>

        {% block errors %}
            <p>
                {% if request.GET.msgc == 'loginerror' %}
                    There was an error trying to log you in, please try again <a href="/login/" style="color:white">here</a>
                {% elif request.GET.msgc == 'alreadyauthenticated' %}
                    You cannot login at the same time with multiple accounts, please <a href="{% url 'security:unicef-logout' %}" style="color:white"> Logout </a> and then login again.
                {% else %}
                    Error during login, please contact the administrator.
                {% endif %}
                {% if user %}
                    <br><br>
                    <a href="{% url 'security:unicef-logout' %}" style="color:white"> Logout </a>
                {% endif %}
            </p>
        {% endblock errors %}
    </div>
</div>
{% endblock content %}
{% block extra_js %}
{% endblock extra_js %}
</body>

</html>
