# Generated by Django 4.2.1 on 2023-11-09 11:12

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("unicef_security", "0003_auto_20220406_2307"),
    ]

    operations = [
        migrations.DeleteModel(
            name="User",
        ),
    ]
