{% extends "admin/base_site.html" %}

{% block footer %}
<div class="module help" style="text-align: center;">
    <p>
        Version: {{ app.version }} | Build Date: {{ app.build_date }} | Commit: {{ app.commit }}
    </p>
</div>
{% endblock footer %}
