{% extends "admin/base.html" %}

{% block content_title %}
    <h1>500 Server Error</h1>
{% endblock content_title %}

{% block content %}
    <p>An error occurred, administrators have been already notified</p>
{% endblock content %}
