{% extends "admin/base.html" %}

{% block content_title %}
    <h1>404 Not Found</h1>
{% endblock content_title %}

{% block content %}
    <p>We can't find the page you're looking for</p>
{% endblock content %}
